@@ -40,6 +40,19 @@ class Request(BaseModel):
     method: str
     scheme: str
     port: Optional[int]
+    # added from aws context
+    aws_request_id: str = None
+    log_group_name: str = None
+    log_stream_name: str = None
+    function_name: str = None
+    memory_limit_in_mb: str = None
+    # added from aws event
+    request_id: str = None
+    domain_name: str = None
+    api_id: str = None
+    # created_urls
+    log_group_url: str = None
+    stream_url: str = None
 
 
 class Times(BaseModel):
@@ -142,6 +155,25 @@ async def make_request_obj_from_request(request: FastAPIRequest):
         scheme=request.url.scheme,
         port=request.url.port,
     )
+
+    aws_fields = ['aws_request_id', 'log_group_name', 'log_stream_name', 'function_name', 'memory_limit_in_mb']
+
+    if 'aws.context' in request.scope:
+        context = request.scope['aws.context']
+        [setattr(request_obj, field, getattr(context, field)) for field in aws_fields]
+
+    if 'aws.event' in request.scope:
+        event = request.scope['aws.event']
+        request_context = event.get('requestContext')
+        if request_context:
+            request_obj.request_id = request_context.get('requestId')
+            request_obj.domain_name = request_context.get('domainName')
+            request_obj.api_id = request_context.get('apiId')
+
+    cloudwatch_base_url = 'https://console.aws.amazon.com/cloudwatch/home?region=us-east-1#logStream:group='
+    request_obj.log_group_url = f'{cloudwatch_base_url}{request_obj.log_group_name}'
+    request_obj.stream_url = f'{request_obj};stream={request_obj.log_stream_name}'.replace('[$LATEST]', '%5B$LATEST%5D')
+
     return request_obj
 
 
